C 11/12/99                                                      DWBA98  POTE-000
      SUBROUTINE POTE(ATIERS,VAL,INM,VR,AM,VS,FO,NQUA,NCHE,AX,KTF,CMU,CVPOTE-001
     1F,WX,JMX,IG)                                                      POTE-002
C CALCULATE THE POTENTIALS.                                             POTE-003
C INPUTS:   ATIERS  MASS OF THE TARGET TO 1/3 RD POWER.                 POTE-004
C           VAL     OPTICAL MODEL PARAMETERS.                           POTE-005
C           INM     NUMBER OF INTEGRATION POINTS.                       POTE-006
C           VS      R AND R**2 IN VS(*,1) AND VS(*,2).                  POTE-007
C           FO      BOUND STATE WAVE FUNCTIONS.                         POTE-008
C           NQUA    BOUND STATE QUANTUM NUMBERS.                        POTE-009
C           NCHE,AX TARGET DESCRIPTION.                                 POTE-010
C           KTF,CMU,CVF TWO BODY INTERACTION.                           POTE-011
C           WX      RADIAL DEPENDENCES OF THE TWO BODY INTERACTION.     POTE-012
C           JMX     MAXIMUM NUMBER OF MULTIPOLES.                       POTE-013
C           IG      1 FOR THE INITIAL STATE, 2 FOR THE FINAL STATE.     POTE-014
C OUTPUT:   VR      POTENTIALS, REAL AND IMAGINARY, CENTRAL AND SPIN    POTE-015
C                       ORBIT.                                          POTE-016
C           VS      FORM FACTORS OF 0+ TRANSITION.                      POTE-017
C                       CENTRAL TERM IN VS(*,3) AND VS(*,4).            POTE-018
C                       SPIN ORBIT TERM IN VS(*,11) AND VS(*,12).       POTE-019
C                       SPIN ORBIT SQUARED TERM IN VS(*,15) AND VS(*,16)POTE-020
C                       FIRST DERIVATIVE TERM IN VS(*,27) AND VS(*,28). POTE-021
C                       SECOND DERIVATIVE TERM IN VS(*,39) AND VS(*,40).POTE-022
C                       PROTON DENSITIES IN VS(*,30).                   POTE-023
C                       NEUTRON DENSITIES IN VS(*,31).                  POTE-024
C                       TOTAL DENSITIES IN VS(*,32).                    POTE-025
C WORKING ARRAY: AM FOR THE MULTIPOLES.                                 POTE-026
C FOR COMMON /NOMBR/   SEE CALC.                                        POTE-027
C FOR COMMON /POIN/   SEE FDIS.                                         POTE-028
C FOR COMMON /GABJ/   SEE MULT.                                         POTE-029
C***********************************************************************POTE-030
      IMPLICIT REAL*8 (A-H,O-Z)                                         POTE-031
      LOGICAL LO,LOX                                                    POTE-032
      DIMENSION VR(INM,4),VAL(20),VS(INM,48),AM(INM,18,1),FO(INM,1),KTF(POTE-033
     17,7,1),WX(INM,1),AX(2,1),NCHE(2,1),NQUA(3,1),CMU(1),CVF(7,6,1)    POTE-034
      COMMON /NOMBR/ H,CCO(5),JMAX,KV,KR,KS,NBCONF,NBPROT,J,KY,ILL(3,4),POTE-035
     1LO(40)                                                            POTE-036
      COMMON /GABJ/ AA,AB,AJ,BJ,CJ,DJ,XG(11),JX                         POTE-037
      COMMON /POIN/ CMY,CCA(2,2),ENE,CRPT,IJMAX,NRY,JMY,LMY,KVA,LOX(8),NPOTE-038
     1VTS,NMUS,NTMS                                                     POTE-039
      DATA PI4 /12.56637/                                               POTE-040
      IF (LO(37)) GO TO 24                                              POTE-041
      IF (IG.EQ.2.AND.LO(32)) RETURN                                    POTE-042
      DO 2 K=1,4                                                        POTE-043
      DO 1 I=1,INM                                                      POTE-044
    1 VR(I,K)=0.D0                                                      POTE-045
    2 CONTINUE                                                          POTE-046
      IF (.NOT.LO(36)) GO TO 10                                         POTE-047
C EXTERNAL POTENTIAL BY POINTS                                          POTE-048
      WRITE (6,1000)                                                    POTE-049
      READ (5,1001) IEXT                                                POTE-050
      IF (IEXT.GT.0) GO TO 3                                            POTE-051
      READ (5,1002) ((VR(I,K),K=1,4),I=1,INM)                           POTE-052
      GO TO 20                                                          POTE-053
    3 IF (LO(34)) WRITE (6,1003)                                        POTE-054
      DO 9 L=1,IEXT                                                     POTE-055
      READ (5,1004) VX,VY,RX,BX,ANX,K                                   POTE-056
      IF (K.GT.4) GO TO 39                                              POTE-057
      RR=0.D0                                                           POTE-058
      DO 8 I=1,INM                                                      POTE-059
      RR=RR+H                                                           POTE-060
      IF (RR.GT.RX+34.5D0*BX) GO TO 4                                   POTE-061
      IF (RR.LT.RX-34.5D0*BX) GO TO 5                                   POTE-062
      FF=DEXP((RR-RX)/BX)                                               POTE-063
      GO TO 6                                                           POTE-064
    4 FF=1.D15                                                          POTE-065
      GO TO 6                                                           POTE-066
    5 FF=0.D0                                                           POTE-067
    6 IF (K.GT.2) GO TO 7                                               POTE-068
      VR(I,K)=VR(I,K)+VX*(1.D0/(1.D0+FF))**(1.D0+ANX)+VY*4.D0*FF/(1.D0+FPOTE-069
     1F)**2                                                             POTE-070
      GO TO 8                                                           POTE-071
    7 VR(I,K)=VR(I,K)+2.D0*VX*FF/(RR*BX*(1.D0+FF)**2)                   POTE-072
    8 CONTINUE                                                          POTE-073
      IF (LO(34)) WRITE (6,1005) K,VX,VY,RX,BX,ANX                      POTE-074
    9 CONTINUE                                                          POTE-075
      GO TO 20                                                          POTE-076
C WOODS-SAXON POTENTIAL. LOOP OVER THE FIVE FORM-FACTORS                POTE-077
   10 WRITE (6,1006) (VAL(I),I=1,16)                                    POTE-078
      DO 19 K=1,5                                                       POTE-079
      IV=3*K-1                                                          POTE-080
      IA=IV+2                                                           POTE-081
      IF (VAL(IV).EQ.0.D0) GO TO 19                                     POTE-082
      RX=VAL(3*K)*ATIERS                                                POTE-083
      RR=0.D0                                                           POTE-084
      IF (VAL(IA).GE.(0.025D0*H)) GO TO 12                              POTE-085
      WRITE (6,1007) K,VAL(IA)                                          POTE-086
      IF (K.GT.2) GO TO 19                                              POTE-087
      VAL(IA)=0.D0                                                      POTE-088
      DO 11 I=1,INM                                                     POTE-089
      RR=RR+H                                                           POTE-090
      IF (RR.GE.RX) GO TO 19                                            POTE-091
   11 VR(I,K)=VR(I,K)+VAL(IV)                                           POTE-092
      GO TO 19                                                          POTE-093
   12 KK=K                                                              POTE-094
      IF (K.GT.2) KK=K-1                                                POTE-095
      DO 18 I=1,INM                                                     POTE-096
      RR=RR+H                                                           POTE-097
      IF (RR.GT.RX+34.5D0*VAL(IA)) GO TO 13                             POTE-098
      IF (RR.LT.RX-34.5D0*VAL(IA)) GO TO 14                             POTE-099
      FF=DEXP((RR-RX)/VAL(IA))                                          POTE-100
      GO TO 15                                                          POTE-101
   13 FF=1.D15                                                          POTE-102
      GO TO 15                                                          POTE-103
   14 FF=0.D0                                                           POTE-104
   15 IF (K.GT.2) GO TO 16                                              POTE-105
      VR(I,K)=VR(I,K)+VAL(IV)*(1.D0/(1.D0+FF))                          POTE-106
      GO TO 18                                                          POTE-107
   16 IF (KK.GT.2) GO TO 17                                             POTE-108
      VR(I,KK)=VR(I,KK)+VAL(IV)*4.D0*FF/(1.D0+FF)**2                    POTE-109
      GO TO 18                                                          POTE-110
   17 VR(I,KK)=VR(I,KK)+2.D0*VAL(IV)*FF/(RR*VAL(IA)*(1.D0+FF)**2)       POTE-111
   18 CONTINUE                                                          POTE-112
   19 CONTINUE                                                          POTE-113
C COULOMB POTENTIAL                                                     POTE-114
   20 RX=VAL(1)*ATIERS                                                  POTE-115
      VX=H/RX                                                           POTE-116
      VY=1.43997595D0*VAL(19)/RX                                        POTE-117
      RR=0.D0                                                           POTE-118
      DO 22 I=1,INM                                                     POTE-119
      RR=RR+VX                                                          POTE-120
      IF (RR.GT.1.D0) GO TO 21                                          POTE-121
      VR(I,1)=VR(I,1)-VY*(1.5D0-0.5D0*RR*RR)                            POTE-122
      GO TO 22                                                          POTE-123
   21 VR(I,1)=VR(I,1)-VY/RR                                             POTE-124
   22 CONTINUE                                                          POTE-125
   23 IF (LO(34)) WRITE (6,1008) (K,(VR(K,I),I=1,4),K=1,INM)            POTE-126
      RETURN                                                            POTE-127
C POTENTIAL OBTAINED FROM THE INTERACTION                               POTE-128
   24 IF (IG.EQ.2.AND.LO(32)) GO TO 27                                  POTE-129
      DO 25 I=1,2                                                       POTE-130
      CCA(I,1)=CCO(I)                                                   POTE-131
   25 CCA(I,2)=CCO(I)                                                   POTE-132
      IF (.NOT.LOX(3)) GO TO 26                                         POTE-133
      READ (5,1004) (CCA(I,2),I=1,2)                                    POTE-134
      WRITE (6,1009) (CCA(I,2),I=1,2)                                   POTE-135
   26 JMY=JMX                                                           POTE-136
      LMY=JMAX+10                                                       POTE-137
      CMY=1.D-6                                                         POTE-138
      NRY=8                                                             POTE-139
      IF (.NOT.LOX(6)) GO TO 27                                         POTE-140
      READ (5,1001) NRY,JMY,LMY,KMY                                     POTE-141
      IF (NRY.EQ.0) NRY=8                                               POTE-142
      IF (JMY.EQ.0) JMY=JMX                                             POTE-143
      IF (LMY.EQ.0) LMY=JMAX+10                                         POTE-144
      IF (KMY.EQ.0) KMY=6                                               POTE-145
      CMY=.1D0**KMY                                                     POTE-146
      WRITE (6,1010) NRY,JMY,LMY,CMY                                    POTE-147
   27 IF (LOX(4)) REWIND NRY                                            POTE-148
      IF (LOX(5)) GO TO 37                                              POTE-149
      LOX(3)=LO(16)                                                     POTE-150
      LOX(6)=LOX(1)                                                     POTE-151
      LO(16)=LOX(2)                                                     POTE-152
      LO(31)=LO(20)                                                     POTE-153
      KVA=KV                                                            POTE-154
      KV=KR+1                                                           POTE-155
      DO 28 I=1,2                                                       POTE-156
   28 CCO(I)=CCA(I,2)                                                   POTE-157
      JX=0                                                              POTE-158
      LO(20)=.TRUE.                                                     POTE-159
      AA=0.D0                                                           POTE-160
      CALL MULT(AM,INM,CMU,-1)                                          POTE-161
      LO(22)=.FALSE.                                                    POTE-162
      IJMAX=0                                                           POTE-163
C LOOP ON THE CONFIGURATIONS                                            POTE-164
      DO 31 K=1,NBCONF                                                  POTE-165
      DO 30 M=1,2                                                       POTE-166
      IF (AX(M,K).EQ.0.) GO TO 30                                       POTE-167
      NPAR=NCHE(M,K)                                                    POTE-168
      NTRO=NCHE(3-M,K)                                                  POTE-169
      IJP=2*NQUA(2,NPAR)+NQUA(3,NPAR)                                   POTE-170
      IJMAX=MAX0(IJMAX,IJP)                                             POTE-171
      AB=NQUA(3,NPAR)*(IJP+1)                                           POTE-172
      IDE=1                                                             POTE-173
      IF (NPAR.GT.NBPROT) IDE=2                                         POTE-174
      CALL GEOM                                                         POTE-175
      CALL DERI(FO(1,NTRO),VS(1,45),INM)                                POTE-176
      CALL DER2(FO(1,NTRO),VS(1,47),INM)                                POTE-177
      DO 29 I=1,INM                                                     POTE-178
      VS(I,43)=FO(I,NTRO)*FO(I,NPAR)                                    POTE-179
      VS(I,IDE+29)=VS(I,IDE+29)+VS(I,43)*AX(M,K)/VS(I,2)/PI4            POTE-180
      VS(I,32)=VS(I,32)+VS(I,43)*AX(M,K)/VS(I,2)/PI4                    POTE-181
      VS(I,44)=0.D0                                                     POTE-182
      VS(I,45)=VS(I,45)*FO(I,NPAR)                                      POTE-183
      VS(I,46)=0.D0                                                     POTE-184
      VS(I,47)=VS(I,47)*FO(I,NPAR)                                      POTE-185
   29 VS(I,48)=0.D0                                                     POTE-186
      CALL PTIP(KTF,CMU,CVF,WX,AM,VS,VS(1,3),VS(1,43),INM,IDE,AX(M,K))  POTE-187
      IF (LO(23)) CALL PTI0(KTF(1,1,KS+1),CVF(1,1,KS+1),WX,VS,VS(1,3),VSPOTE-188
     1(1,43),FO(1,NPAR),FO(1,NPAR),INM,IDE,G)                           POTE-189
   30 CONTINUE                                                          POTE-190
   31 CONTINUE                                                          POTE-191
      IF (LOX(2)) GO TO 34                                              POTE-192
      RX=VAL(1)*ATIERS                                                  POTE-193
      VX=H/RX                                                           POTE-194
      VY=1.43997595D0*VAL(19)/RX                                        POTE-195
      RR=0.D0                                                           POTE-196
      DO 33 I=1,INM                                                     POTE-197
      RR=RR+VX                                                          POTE-198
      IF (RR.GT.1.) GO TO 32                                            POTE-199
      VS(I,3)=VS(I,3)+VY*(1.5D0-0.5D0*RR*RR)                            POTE-200
      GO TO 33                                                          POTE-201
   32 VS(I,3)=VS(I,3)+VY/RR                                             POTE-202
   33 CONTINUE                                                          POTE-203
      GO TO 35                                                          POTE-204
   34 VAL(19)=INM*H*CCO(5)/1.43997595D0                                 POTE-205
   35 DO 36 I=1,INM                                                     POTE-206
      VR(I,1)=-VS(I,3)-2.D0*VS(I,11)                                    POTE-207
      VR(I,2)=-VS(I,4)-2.D0*VS(I,12)                                    POTE-208
      VR(I,3)=-2.D0*VS(I,11)                                            POTE-209
   36 VR(I,4)=-2.D0*VS(I,12)                                            POTE-210
      LOX(8)=ILL(3,1).EQ.0                                              POTE-211
      IF (.NOT.LOX(4)) GO TO 38                                         POTE-212
      WRITE (NRY) INM,H,LOX                                             POTE-213
      WRITE (NRY) (VS(I,3),I=1,INM),(VS(I,4),I=1,INM),(VS(I,11),I=1,INM)POTE-214
     1,(VS(I,12),I=1,INM),(VS(I,15),I=1,INM),(VS(I,16),I=1,INM),(VS(I,27POTE-215
     2),I=1,INM),(VS(I,28),I=1,INM),(VS(I,39),I=1,INM),(VS(I,40),I=1,INMPOTE-216
     3)                                                                 POTE-217
      WRITE (NRY) ((VR(I,L),I=1,INM),L=1,4)                             POTE-218
      GO TO 38                                                          POTE-219
   37 READ (NRY) INX,HX,LOX                                             POTE-220
      IF ((INX.NE.INM).OR.(HX.NE.H)) GO TO 40                           POTE-221
      LOX(5)=.TRUE.                                                     POTE-222
      READ (NRY) (VS(I,3),I=1,INM),(VS(I,4),I=1,INM),(VS(I,11),I=1,INM),POTE-223
     1(VS(I,12),I=1,INM),(VS(I,15),I=1,INM),(VS(I,16),I=1,INM),(VS(I,27)POTE-224
     2,I=1,INM),(VS(I,28),I=1,INM),(VS(I,39),I=1,INM),(VS(I,40),I=1,INM)POTE-225
      READ (NRY) ((VR(I,L),I=1,INM),L=1,4)                              POTE-226
   38 IF (LOX(7)) WRITE (6,1011) (I,VS(I,1),VS(I,30),VS(I,31),VS(I,32),IPOTE-227
     1=1,INM)                                                           POTE-228
      IF (.NOT.LO(34)) RETURN                                           POTE-229
      IF (ILL(3,1).EQ.0) GO TO 23                                       POTE-230
      WRITE (6,1012) (I,VS(I,1),VS(I,3),VS(I,4),VS(I,11),VS(I,12),I=1,INPOTE-231
     1M)                                                                POTE-232
      WRITE (6,1013) (I,VS(I,1),VS(I,15),VS(I,16),VS(I,27),VS(I,28),VS(IPOTE-233
     1,39),VS(I,40),I=1,INM)                                            POTE-234
      RETURN                                                            POTE-235
   39 WRITE (6,1014) K                                                  POTE-236
      GO TO 41                                                          POTE-237
   40 WRITE (6,1015) NRY,INX,INM,HX,H                                   POTE-238
   41 WRITE (6,1016)                                                    POTE-239
      RETURN                                                            POTE-240
 1000 FORMAT (/10X,18HEXTERNAL POTENTIAL)                               POTE-241
 1001 FORMAT (14I5)                                                     POTE-242
 1002 FORMAT (4F15.6)                                                   POTE-243
 1003 FORMAT (10H POTENTIAL,4X,6HVOLUME,12X,7HSURFACE,10X,6HRADIUS,6X,14POTE-244
     1HDIFFUSE. POWER/)                                                 POTE-245
 1004 FORMAT (5F10.5,I5)                                                POTE-246
 1005 FORMAT (5X,I5,F15.6,F18.6,F13.6,F12.6,F10.6)                      POTE-247
 1006 FORMAT (/18H OPTICAL POTENTIAL/15X,D15.6/(3D15.6))                POTE-248
 1007 FORMAT (5X,I1,36H TH FORM-FACTOR ,SURFACE DIFFUSENESS,D11.4,22H CHPOTE-249
     1ANGE IN SQUARE WELL)                                              POTE-250
 1008 FORMAT (/6H POINT,8X,6HV-REAL,9X,11HV-IMAGINARY,4X,8HVLS-REAL,7X,1POTE-251
     13HVLS-IMAGINARY//(2X,I5,2X,4F15.8))                               POTE-252
 1009 FORMAT (35H NEW COULOMB TWO-BODY INTERACTIONS:,2F10.5)            POTE-253
 1010 FORMAT (10X,11HUSE OF FILE,I4/8X,I4,28H MULTIPOLES FOR THE EXCHANGPOTE-254
     1E/8X,I4,27H VALUES OF ANGULAR MOMENTUM/8X,D10.3,39H MINIMUM EFFECTPOTE-255
     2 ON ELASTIC PHASE SHIFTS/)                                        POTE-256
 1011 FORMAT (9X,1HR,12X,14HPROTON DENSITY,5X,15HNEUTRON DENSITY,7X,13HTPOTE-257
     1OTAL DENSITY/(2X,I3,1P,D11.3,3D20.6))                             POTE-258
 1012 FORMAT (11X,1HR,13X,11HINDEPENDENT,20X,5HALPHA/(2X,I3,1P,D11.3,4D1POTE-259
     14.6))                                                             POTE-260
 1013 FORMAT (11X,1HR,14X,8HALPHA**2,16X,16HFIRST DERIVATIVE,11X,17HSECOPOTE-261
     1ND DERIVATIVE/(2X,I3,1P,D11.3,6D14.6))                            POTE-262
 1014 FORMAT (19H TOO LARGE VALUE K=,I4,15H   LIMITED TO 4)             POTE-263
 1015 FORMAT (22H ERROR IN READING FILE,I4,2H :,I4,17H STEPS INSTEAD OF,POTE-264
     1I4,3H OF,D10.3,11H INSTEAD OF,D10.3,7H FERMIS)                    POTE-265
 1016 FORMAT (25H ***** STOP IN POTE *****)                             POTE-266
      END                                                               POTE-267
