C 03/04/98                                                      DWBA98  PTIV-000
      SUBROUTINE PTIV(K,AM,CMU,H,LOO,IBB,BB,NBB,XX,VD,VS,VX,XA,INM,KW,XHPTIV-001
     1,KZ)                                                              PTIV-002
C COMPUTE THE NON LOCAL POTENTIAL FOR A CONFIGURATION OF THE TARGET FOR PTIV-003
C A RADIAL DEPENDENCE AND A FIXED RANGE.                                PTIV-004
C INPUT:  K    INDEX OF THE RANGE.                                      PTIV-005
C         AM   TABLE OF MULTIPOLES.                                     PTIV-006
C         CMU  VALUE OF THE RANGE.                                      PTIV-007
C         H    STEP SIZE.                                               PTIV-008
C         LOO  LOGICAL CONTROL INDICATING IF A STEP IS ALREADY PERFORMEDPTIV-009
C         IBB  LIMITS OF DO LOOPS.                                      PTIV-010
C         BB   WEIGHTS FOR SOME TERMS.                                  PTIV-011
C         NBB  NUMBER OF DIFFERENT OPERATIONS.                          PTIV-012
C         XX   STRENGTH OF EACH MULTIPOLE.                              PTIV-013
C         VD   BOUND STATE FUNCTION AND DERIVATIVES.                    PTIV-014
C         VS   R AND R**2 IN VS(*,1) AND VS(*,2).                       PTIV-015
C         INM  NUMBER OF INTEGRATION POINTS.                            PTIV-016
C         KW   ADDRESS OF THE IMAGINARY RADIAL DEPENDENCE.              PTIV-017
C         XH   RELATIVE SIGNS OF COEFFICIENTS XH FOR THE TWO PARTICLES. PTIV-018
C         KZ   ADDRESS OF THE REAL RADIAL DEPENDENCE.                   PTIV-019
C OUTPUT: XA   UPDATED VALUES IN XA(*,*,I) FOR I=1 TO 6.                PTIV-020
C WORKING AREA:  XA(*,*,7)                                              PTIV-021
C                VD(*,I) FOR UNUSED VALUES OF I.                        PTIV-022
C***********************************************************************PTIV-023
      IMPLICIT REAL*8 (A-H,O-Z)                                         PTIV-024
      LOGICAL LOO(8)                                                    PTIV-025
      DIMENSION IBB(NBB,7),BB(NBB),XX(2,NBB),AM(INM,18,1),CMU(1),VX(INM,PTIV-026
     11),VS(INM,2),VD(INM,1),XA(INM,INM,8),XH(11)                       PTIV-027
      COMMON /GABJ/ AA,AB,AJ,BJ,CJ,DJ,XG(11),JX                         PTIV-028
      IS1=-1                                                            PTIV-029
    1 IA=0                                                              PTIV-030
      IS2=10                                                            PTIV-031
      IK=0                                                              PTIV-032
C SUM ON THE GEOMETRICAL COEFFICIENTS OF PARTICLE 2.                    PTIV-033
      DO 30 JJ=1,NBB                                                    PTIV-034
      Z1=0.D0                                                           PTIV-035
      Y1=0.D0                                                           PTIV-036
      J1=IBB(JJ,1)                                                      PTIV-037
      J3=J1                                                             PTIV-038
      IF (IBB(JJ,7).LT.0) J3=J3-1                                       PTIV-039
      J2=IBB(JJ,2)                                                      PTIV-040
      DO 2 JB=J1,J2                                                     PTIV-041
      IF ((XX(1,JB).EQ.0.).AND.(XX(2,JB).EQ.0.)) GO TO 2                PTIV-042
      ZZ1=BB(JJ)                                                        PTIV-043
      IF (JB.NE.J3) ZZ1=ZZ1*XG(JB-J3)*XH(JB-J3)                         PTIV-044
      Z1=Z1+ZZ1*XX(1,JB)                                                PTIV-045
      Y1=Y1+ZZ1*XX(2,JB)                                                PTIV-046
    2 CONTINUE                                                          PTIV-047
      IF ((Z1.EQ.0.).AND.(Y1.EQ.0.)) GO TO 30                           PTIV-048
      IF ((IA.EQ.IBB(JJ,4)).AND.(IS1.EQ.IBB(JJ,5))) GO TO 10            PTIV-049
      IA=IBB(JJ,4)+1                                                    PTIV-050
      IS1=IBB(JJ,5)                                                     PTIV-051
      IB=IA                                                             PTIV-052
      IS=IS1                                                            PTIV-053
      IX1=4                                                             PTIV-054
C MULTIPLICATION BY A POWER OF R.                                       PTIV-055
      LOO(6)=KZ.EQ.0.OR.LOO(2).OR.LOO(3)                                PTIV-056
    3 ID=IB                                                             PTIV-057
      IF (IS.EQ.0) GO TO 7                                              PTIV-058
      ID=IX1+1                                                          PTIV-059
      IF (IS.LT.0) GO TO 5                                              PTIV-060
      DO 4 I=1,INM                                                      PTIV-061
    4 VD(I,ID)=VD(I,IB)*VS(I,IS)                                        PTIV-062
      GO TO 7                                                           PTIV-063
    5 IS=-IS                                                            PTIV-064
      DO 6 I=1,INM                                                      PTIV-065
    6 VD(I,ID)=VD(I,IB)/VS(I,IS)                                        PTIV-066
    7 IE=ID                                                             PTIV-067
      LOO(IX1)=.TRUE.                                                   PTIV-068
C MULTIPLICATION BY A RADIAL DEPENDENCE.                                PTIV-069
      IF (LOO(6)) GO TO 9                                               PTIV-070
      LOO(IX1)=KW.EQ.KZ                                                 PTIV-071
      IE=2*IX1+7                                                        PTIV-072
      DO 8 I=1,INM                                                      PTIV-073
      IF (LOO(IX1)) GO TO 8                                             PTIV-074
      VD(I,IE+1)=VD(I,ID)*VX(I,KW)                                      PTIV-075
    8 VD(I,IE)=VD(I,ID)*VX(I,KZ)                                        PTIV-076
    9 IF (IX1.EQ.5) GO TO 11                                            PTIV-077
      IH=IE                                                             PTIV-078
   10 IF (IS2.EQ.IBB(JJ,6)) GO TO 12                                    PTIV-079
      IS2=IBB(JJ,6)                                                     PTIV-080
      IS=IS2                                                            PTIV-081
      IB=1                                                              PTIV-082
      IX1=5                                                             PTIV-083
      LOO(6)=(KZ.EQ.0).OR.(LOO(1).AND.(.NOT.LOO(2))).OR.LOO(3)          PTIV-084
      GO TO 3                                                           PTIV-085
   11 IC=IE                                                             PTIV-086
   12 IF (IK.EQ.IBB(JJ,3)) GO TO 15                                     PTIV-087
      IK=IBB(JJ,3)                                                      PTIV-088
C CONSTRUCTION OF THE MATRIX FOR A MULTIPOLE.                           PTIV-089
      DO 14 I=1,INM                                                     PTIV-090
      DO 13 L=I,INM                                                     PTIV-091
      XA(L,I,7)=AM(I,IK+7,K)*AM(L,IK,K)                                 PTIV-092
   13 XA(I,L,7)=AM(I,IK+7,K)*AM(L,IK,K)                                 PTIV-093
   14 XA(I,I,7)=XA(I,I,7)-H*H*CMU(K)/12.D0/VS(I,2)                      PTIV-094
   15 IJ=IABS(IBB(JJ,7))                                                PTIV-095
      IF (LOO(3)) GO TO 25                                              PTIV-096
C ADDITION IN XA OF THE CONTRIBUTION.                                   PTIV-097
      DO 17 I=1,INM                                                     PTIV-098
      DO 16 L=1,INM                                                     PTIV-099
      XA(L,I,IJ)=XA(L,I,IJ)+XA(L,I,7)*VD(I,IC)*VD(L,IH)*Z1              PTIV-100
   16 XA(L,I,IJ+1)=XA(L,I,IJ+1)+XA(L,I,7)*VD(I,IC)*VD(L,IH)*Y1          PTIV-101
   17 CONTINUE                                                          PTIV-102
      IF (LOO(4)) GO TO 20                                              PTIV-103
      DO 19 I=1,INM                                                     PTIV-104
      DO 18 L=1,INM                                                     PTIV-105
      XA(L,I,IJ)=XA(L,I,IJ)-XA(L,I,7)*VD(I,IC)*VD(L,IH+1)*Y1            PTIV-106
   18 XA(L,I,IJ+1)=XA(L,I,IJ+1)+XA(L,I,7)*VD(I,IC)*VD(L,IH+1)*Z1        PTIV-107
   19 CONTINUE                                                          PTIV-108
   20 IF (LOO(5)) GO TO 30                                              PTIV-109
      DO 22 I=1,INM                                                     PTIV-110
      DO 21 L=1,INM                                                     PTIV-111
      XA(L,I,IJ)=XA(L,I,IJ)-XA(L,I,7)*VD(I,IC+1)*VD(L,IH)*Y1            PTIV-112
   21 XA(L,I,IJ+1)=XA(L,I,IJ+1)+XA(L,I,7)*VD(I,IC+1)*VD(L,IH)*Z1        PTIV-113
   22 CONTINUE                                                          PTIV-114
      IF (LOO(4)) GO TO 30                                              PTIV-115
      DO 24 I=1,INM                                                     PTIV-116
      DO 23 L=1,INM                                                     PTIV-117
      XA(L,I,IJ)=XA(L,I,IJ)-XA(L,I,7)*VD(I,IC+1)*VD(L,IH+1)*Z1          PTIV-118
   23 XA(L,I,IJ+1)=XA(L,I,IJ+1)-XA(L,I,7)*VD(I,IC+1)*VD(L,IH+1)*Y1      PTIV-119
   24 CONTINUE                                                          PTIV-120
      GO TO 30                                                          PTIV-121
   25 DO 27 I=1,INM                                                     PTIV-122
      DO 26 L=1,INM                                                     PTIV-123
      XA(L,I,IJ)=XA(L,I,IJ)+XA(L,I,7)*VD(I,IC)*VD(L,IH)*VX(I+L,KZ)*Z1   PTIV-124
   26 XA(L,I,IJ+1)=XA(L,I,IJ+1)+XA(L,I,7)*VD(I,IC)*VD(L,IH)*VX(I+L,KZ)*YPTIV-125
     11                                                                 PTIV-126
   27 CONTINUE                                                          PTIV-127
      IF (KW.EQ.KZ) GO TO 30                                            PTIV-128
      DO 29 I=1,INM                                                     PTIV-129
      DO 28 L=1,INM                                                     PTIV-130
      XA(L,I,IJ)=XA(L,I,IJ)-XA(L,I,7)*VD(I,IC)*VD(L,IH)*VX(I+L,KW)*Y1   PTIV-131
   28 XA(L,I,IJ+1)=XA(L,I,IJ+1)+XA(L,I,7)*VD(I,IC)*VD(L,IH)*VX(I+L,KW)*ZPTIV-132
     11                                                                 PTIV-133
   29 CONTINUE                                                          PTIV-134
   30 CONTINUE                                                          PTIV-135
      IF (.NOT.LOO(1)) RETURN                                           PTIV-136
      LOO(2)=.NOT.LOO(2)                                                PTIV-137
      IF (LOO(2)) GO TO 1                                               PTIV-138
      END                                                               PTIV-139
