C 20/03/97                                                      DWBA98  FCOU-000
      SUBROUTINE FCOU(L,ETA,RO,F,FP,G,GP,IEXP,SIGMA)                    FCOU-001
C COULOMB FUNCTIONS FOR RHO > 0 AND -500 < ETA < 500  FROM - DFCOUL     FCOU-002
C FOR THE MATHEMATICAL DESCRIPTION SEE CHR. BARDIN ET. AL. CEA-N-906    FCOU-003
C OR BARDIN ET AL. COMP. PHYSICS COMM. VOL 3 (1972) PAGES 73-87         FCOU-004
C NUMERICAL PRECISION: AT LEAST 8 SIGNIFICANT FIGURES, EXCEPT FOR       FCOU-005
C THE REGION -8 < ETA < -6 AND RO < 125/6                               FCOU-006
C THE CALCULATION OF THE PHASE SHIFTS HAS BEEN REMOVED EXCEPT FOR L=0   FCOU-007
C INPUTS:    L      FINAL ANGULAR MOMENTUM REQUIRED.                    FCOU-008
C            ETA    COULOMB PARAMETER.                                  FCOU-009
C            RO     RADIUS.                                             FCOU-010
C OUTPUTS:   F      REGULAR FUNCTION.                                   FCOU-011
C            FP     DERIVATIVE OF THE REGULAR FUNCTION.                 FCOU-012
C            G      IRREGULAR FUNCTION.                                 FCOU-013
C            GP     DERIVATIVE OF THE IRREGULAR FUNCTION.               FCOU-014
C            IEXP   POWERS OF 10 BY WHICH TO MULTIPLY THE IRREGULAR     FCOU-015
C                   FUNCTIONS AND DIVIDE THE REGULAR , IF THIS POWER    FCOU-016
C                   EXCEEDS 15.                                         FCOU-017
C            SIGMA(1)  COULOMB PHASE SHIFTS FOR L=0.                    FCOU-018
C***********************************************************************FCOU-019
      IMPLICIT REAL*8 (A-H,O-Z)                                         FCOU-020
      DIMENSION F(1),FP(1),G(1),GP(1),IEXP(1),SIGMA(1)                  FCOU-021
      IF (RO.GT.0.D0.AND.DABS(ETA).LE.500.D0) GO TO 1                   FCOU-022
      WRITE (6,1000) ETA,RO                                             FCOU-023
      STOP                                                              FCOU-024
C CALCULATION OF THE COULOMB FUNCTIONS FOR L=0                          FCOU-025
    1 CALL FCZ0(ETA,RO,F1,FP1,G1,GP1,IEXP1,SIGMA1)                      FCOU-026
      F(1)=F1                                                           FCOU-027
      FP(1)=FP1                                                         FCOU-028
      G(1)=G1                                                           FCOU-029
      GP(1)=GP1                                                         FCOU-030
      IEXP(1)=IEXP1                                                     FCOU-031
      SIGMA(1)=SIGMA1                                                   FCOU-032
      IF (L.LE.0) RETURN                                                FCOU-033
      LINF=0                                                            FCOU-034
      LIN=1                                                             FCOU-035
      IND=0                                                             FCOU-036
      L1=L+1                                                            FCOU-037
      ETAC=ETA*ETA                                                      FCOU-038
      IF ((ETA.GT.0.D0.AND.RO.LT.ETA+ETA.OR.RO.LT.ETA+DSQRT(ETAC+1.D0)))FCOU-039
     1 GO TO 7                                                          FCOU-040
      IF (RO.GE.ETA+DSQRT(ETAC+L*(L+1))) GO TO 5                        FCOU-041
    2 ROINF=ETA+DSQRT(ETAC+LINF*(LINF+1))                               FCOU-042
      IF (RO.LT.ROINF) GO TO 3                                          FCOU-043
      IF (LINF.GE.L) GO TO 4                                            FCOU-044
      LINF=LINF+1                                                       FCOU-045
      GO TO 2                                                           FCOU-046
    3 IND=1                                                             FCOU-047
    4 LIN=LINF+1                                                        FCOU-048
    5 XM=1.D0                                                           FCOU-049
      IF (IND.EQ.0) LIN=L1                                              FCOU-050
C UPWARD RECURSION FOR THE REGULAR AND IRREGULAR FUNCTIONS.             FCOU-051
      DO 6 J=2,LIN                                                      FCOU-052
      ZIG=(DSQRT(ETAC+XM*XM))/XM                                        FCOU-053
      ZAG=ETA/XM+XM/RO                                                  FCOU-054
      F(J)=(ZAG*F(J-1)-FP(J-1))/ZIG                                     FCOU-055
      FP(J)=ZIG*F(J-1)-ZAG*F(J)                                         FCOU-056
      G(J)=(ZAG*G(J-1)-GP(J-1))/ZIG                                     FCOU-057
      GP(J)=ZIG*G(J-1)-ZAG*G(J)                                         FCOU-058
      IEXP(J)=IEXP(1)                                                   FCOU-059
    6 XM=XM+1.D0                                                        FCOU-060
      IF (IND.EQ.0) RETURN                                              FCOU-061
C DESCENDING RECURSION FOR THE REGULAR FUNCTION                         FCOU-062
    7 FTEST=F(LIN)                                                      FCOU-063
      FPTEST=FP(LIN)                                                    FCOU-064
      LMAX=LINF+25+IDINT(5.D0*DABS(ETA))                                FCOU-065
      IF (LMAX.LT.L) LMAX=L                                             FCOU-066
      FI=1.D0                                                           FCOU-067
      FPI=1.D0                                                          FCOU-068
C ANGULAR MOMENTUM GREATER THAN THE MAXIMUM REQUIRED                    FCOU-069
    8 XM=LMAX+1                                                         FCOU-070
      ZIG=(DSQRT(ETAC+XM*XM))/XM                                        FCOU-071
      ZAG=ETA/XM+XM/RO                                                  FCOU-072
      FL=(ZAG*FI+FPI)/ZIG                                               FCOU-073
      FPL=ZAG*FL-ZIG*FI                                                 FCOU-074
      IF (DABS(FL).LT.1.D15.AND.DABS(FPL).LT.1.D15) GO TO 9             FCOU-075
      FL=FL*1.D-15                                                      FCOU-076
      FPL=FPL*1.D-15                                                    FCOU-077
    9 FI=FL                                                             FCOU-078
      FPI=FPL                                                           FCOU-079
      IF (LMAX.LE.L) GO TO 11                                           FCOU-080
   10 LMAX=LMAX-1                                                       FCOU-081
      GO TO 8                                                           FCOU-082
C ANGULAR MOMENTUM SMALLER THAN THAT REQUIRED                           FCOU-083
   11 F(LMAX+1)=FL                                                      FCOU-084
      FP(LMAX+1)=FPL                                                    FCOU-085
      IF (LMAX.GT.LINF) GO TO 10                                        FCOU-086
      FACT=FTEST/F(LIN)                                                 FCOU-087
      FACTP=FPTEST/FP(LIN)                                              FCOU-088
      INDICE=IEXP(1)/15                                                 FCOU-089
      XM=LINF                                                           FCOU-090
C NORMALISATION OF THE RESULTS OF THE DESCENDING RECURSION AND          FCOU-091
C UPWARDS RECURSION FOR THE IRREGULAR FUNCTION.                         FCOU-092
      DO 13 J=LIN,L1                                                    FCOU-093
      F(J)=F(J)*FACT                                                    FCOU-094
      FP(J)=FP(J)*FACTP                                                 FCOU-095
      IF (J.EQ.1) GO TO 13                                              FCOU-096
      ZIG=(DSQRT(ETAC+XM*XM))/XM                                        FCOU-097
      ZAG=ETA/XM+XM/RO                                                  FCOU-098
      G(J)=(ZAG*G(J-1)-GP(J-1))/ZIG                                     FCOU-099
      GP(J)=ZIG*G(J-1)-ZAG*G(J)                                         FCOU-100
      IF (DABS(G(J)).LT.1.D15.AND.DABS(GP(J)).LT.1.D15) GO TO 12        FCOU-101
      G(J)=G(J)/1.D15                                                   FCOU-102
      GP(J)=GP(J)/1.D15                                                 FCOU-103
      INDICE=INDICE+1                                                   FCOU-104
   12 IEXP(J)=INDICE*15                                                 FCOU-105
      A=DLOG10(DABS(FP(J)))+DLOG10(DABS(G(J)))                          FCOU-106
      B=0.D0                                                            FCOU-107
      IF (A.GE.0.D0) B=1.D0                                             FCOU-108
      I1=B+A                                                            FCOU-109
      I2=B+DLOG10(DABS(GP(J)))+DLOG10(DABS(F(J)))                       FCOU-110
      F(J)=F(J)*1.D1**(-I2)                                             FCOU-111
      FP(J)=FP(J)*1.D1**(-I1)                                           FCOU-112
   13 XM=XM+1.D0                                                        FCOU-113
      RETURN                                                            FCOU-114
 1000 FORMAT (19H  FCOU   ***  ETA =,1P,D13.5,8H,  RHO =,D13.5,25H   ARGFCOU-115
     1UMENT OUT OFF RANGE)                                              FCOU-116
      END                                                               FCOU-117
