C 29/03/98                                                      DWBA98  CORH-000
      SUBROUTINE CORH(E1,E2,LM,XE1,XE2,ZR,ZI,AM,BM,LX,IDMT,LO)          CORH-001
C  CALCULATE THE INTEGRALS (0,2;L) IN BIEDENHARN'S NOTATION FROM L=0    CORH-002
C  TO LM-1 AND KI*KF=1 BY UPWARD OR DOWNWARD RECURSION.                 CORH-003
C  THE LIMIT OF STABILITY OF THE UPWARD RECURSION ON AN IBM-360WAS      CORH-004
C  FOUND TO BE OF THE ORDER OF   LM*|EF-EI|/(EF+EI) < 3 .               CORH-005
C INPUTS:  E1,E2   COULOMB PARAMETERS.                                  CORH-006
C          LM      NUMBER OF INTEGRALS.                                 CORH-007
C          XE1,XE2 COULOMB PHASE SHIFTS FOR L=0.                        CORH-008
C          BM      WORKING AREA FOR THE CALCULATION OF  (0,1;0)AND      CORH-009
C                          AND (0,1;1)                                  CORH-010
C          LX      DIMENSION OF THE WORKING AREA.                       CORH-011
C          IDMT    DIMENSION OF THE TOTAL WORKING AREA.                 CORH-012
C          LO      LOGICAL CONTROLS.                                    CORH-013
C OUTPUTS: ZR,ZI   REAL AND IMAGINARY PARTS OF LOG(GAMMA(0.,EI-EF))     CORH-014
C          AM      INTEGRALS                                            CORH-015
C***********************************************************************CORH-016
      IMPLICIT REAL*8 (A-H,O-Z)                                         CORH-017
      LOGICAL LL,LO(40)                                                 CORH-018
      DIMENSION AM(1),BB(2),B(7),BM(4,1)                                CORH-019
      DATA B /.8333333333333333D-01,-.2777777777777778D-2,.7936507936507CORH-020
     19365D-3,-.5952380952380952D-3,.84175084175D-3,-.19175269D-2,.641D-CORH-021
     202/                                                               CORH-022
      IF (E1.NE.E2) GO TO 2                                             CORH-023
C IF EI=EF=E   (0,1;L)=(PI-PI*COTH(PI*E)-1/E+SUM OVER N FROM 0 TO L OF  CORH-024
C                2*E/(N**2+E**2))/2/(2*L+1)                             CORH-025
      A1=1.5707963267948966D0                                           CORH-026
      B1=DEXP(-6.2831853071795864D0*E1)                                 CORH-027
      IF (E1.NE.0.D0) A1=A1-1.5707963267948966D0*(B1+1.D0)/(1.D0-B1)+.5DCORH-028
     10/E1                                                              CORH-029
      B2=0.D0                                                           CORH-030
      DO 1 I=1,LM                                                       CORH-031
      B1=B2                                                             CORH-032
      B2=B2+1.D0                                                        CORH-033
      AM(I)=A1/(B1+B2)                                                  CORH-034
    1 A1=A1+E1/(B2**2+E1*E2)                                            CORH-035
      RETURN                                                            CORH-036
C FIND THE SMALLER OF (E1,E2)                                           CORH-037
    2 EI=DMIN1(E1,E2)                                                   CORH-038
      EF=DMAX1(E1,E2)                                                   CORH-039
      IF (E1.EQ.EF) GO TO 3                                             CORH-040
      XEI=XE1                                                           CORH-041
      XEF=XE2                                                           CORH-042
      GO TO 4                                                           CORH-043
    3 XEI=XE2                                                           CORH-044
      XEF=XE1                                                           CORH-045
    4 EX=EF-EI                                                          CORH-046
C CALCULATE LOG(GAMMA(0.,EI-EF))                                        CORH-047
      B2=-DATAN(EX/11.D0)                                               CORH-048
      B5=121.D0+EX**2                                                   CORH-049
      B1=.5D0*DLOG(B5)                                                  CORH-050
      ZR=.91893853320467274D0+10.5D0*B1+EX*B2-11.D0-DLOG(EX)            CORH-051
      ZI=10.5D0*B2+EX-EX*B1+1.5707963267948966D0                        CORH-052
      B1=11.D0/B5                                                       CORH-053
      B2=EX/B5                                                          CORH-054
      B3=B1**2-B2**2                                                    CORH-055
      B4=2.D0*B1*B2                                                     CORH-056
      DO 5 I=1,7                                                        CORH-057
      ZR=ZR+B(I)*B1                                                     CORH-058
      ZI=ZI+B(I)*B2                                                     CORH-059
      B5=B1*B3-B2*B4                                                    CORH-060
      B2=B1*B4+B2*B3                                                    CORH-061
    5 B1=B5                                                             CORH-062
      DO 6 I=1,10                                                       CORH-063
      AR=I                                                              CORH-064
      ZR=ZR-.5D0*DLOG(AR**2+EX**2)                                      CORH-065
    6 ZI=ZI+DATAN(EX/AR)                                                CORH-066
C CALCULATION OF (0,1;0) AND (0,1;1) MINUS THE FIRST TERM OF THE        CORH-067
C   HYPERGEOMETRIC FUNCTION.                                            CORH-068
C  (0,1;L) = 2*EI*EF/(EI+EF)**2 * EXP( -PI*|EF-EI|/2) * REAL PART OF    CORH-069
C   (|EF-EI|/(EF+EI))**(I*(EF-EI))*GAMMA(I*(EI-EF))*EXP(I*(XEF-XEI))*   CORH-070
C   2F1(L+1-I*EI,L+1+I*EF;1+I*EF-I*EI;((EF-EI)/(EF+EI))**2)             CORH-071
      EIF=EI*EF                                                         CORH-072
      EIPF=EI+EF                                                        CORH-073
      EZ=EX**2                                                          CORH-074
      E=(EX/EIPF)**2                                                    CORH-075
      A3=2.D0*EIF*DEXP(ZR-1.5707963267948966D0*EX)/EIPF**2              CORH-076
      A4=ZI+XEF-XEI+DLOG(EX/EIPF)*EX                                    CORH-077
      AX1=A3*DCOS(A4)                                                   CORH-078
      AX2=A3*DSIN(A4)                                                   CORH-079
      C1=AX1                                                            CORH-080
      C2=AX2                                                            CORH-081
      C4=0.D0                                                           CORH-082
      DO 9 L=1,2                                                        CORH-083
      BB(L)=0.D0                                                        CORH-084
      C5=0.D0                                                           CORH-085
      DO 7 N=1,500                                                      CORH-086
      C5=C5+1.D0                                                        CORH-087
      B1=(C4+C5)**2+EIF                                                 CORH-088
      B2=(C4+C5)*EX                                                     CORH-089
      B5=E/(C5*(C5**2+EZ))                                              CORH-090
      B3=(B1*C5+B2*EX)*B5                                               CORH-091
      B4=(C5*B2-EX*B1)*B5                                               CORH-092
      C3=C1*B3-C2*B4                                                    CORH-093
      C2=C1*B4+C2*B3                                                    CORH-094
      C1=C3                                                             CORH-095
      BB(L)=BB(L)+C1                                                    CORH-096
      IF (DABS(C1)+DABS(C2).LT.DABS(BB(L))*1.D-16) GO TO 8              CORH-097
    7 CONTINUE                                                          CORH-098
      LI=L-1                                                            CORH-099
      WRITE (6,1000) LI,EI,EF,BB(L),C1,C2                               CORH-100
    8 B1=1.D0+EIF                                                       CORH-101
      B3=(1.D0-E)/DSQRT(B1*B1+EX*EX)                                    CORH-102
      C4=1.D0                                                           CORH-103
      C1=B3*(AX1*B1-AX2*EX)                                             CORH-104
    9 C2=B3*(AX2*B1+AX1*EX)                                             CORH-105
C CALCULATION OF  (-1,2;1) AND (-1,2:2) WITH    (-1,N+1;L) =            CORH-106
C    ( EF*|L+I*EI|*(0,N;L) - EI*|L+I*EF|*(0,N;L+1) )/SQRT(EI*EF)/L/N    CORH-107
      EI2=EI**2                                                         CORH-108
      EF2=EF**2                                                         CORH-109
      EITF=(EF2+EI2)/EIF                                                CORH-110
      EIMF=(EF2-EI2)/(2*EIF)                                            CORH-111
      ES=DSQRT(EIF)                                                     CORH-112
      AI2=DSQRT(1.D0+EI2)                                               CORH-113
      AF2=DSQRT(1.D0+EF2)                                               CORH-114
      AI3=DSQRT(4.D0+EI2)                                               CORH-115
      B1=EX*EF*((EF+3.D0*EI+EX*EI2)*AX1+4.D0*EI2*AX2)/AI2/EIPF**2       CORH-116
      B2=EX*EI*((3.D0*EF+5.D0*EI+EF*EF2+5.D0*EF2*EI+3.D0*EF*EI2-EI2*EI+ECORH-117
     1X*EF2*EI2)*AX1+(4.D0*EF2*EI2+6.D0*EI2-2.D0*EF2)*AX2)/(AF2*AI2*EIPFCORH-118
     2**2)                                                              CORH-119
      AM2=(EF*AI2*BB(1)-EI*AF2*BB(2)+B1)/ES                             CORH-120
      AM3=(EI*AF2*AI2*BB(1)-(1.5D0*EI2-.5D0*EF2+EI2*EF2)*BB(2)/EF+B2)/(ECORH-121
     1S*AI3)                                                            CORH-122
C CALCULATION OF (1,2;0) FOR THE NORMALISATION OF THE DOWNWARD RECURSIONCORH-123
      AZ=(EI*AF2*BB(1)-EF*AI2*BB(2)+EX*EI*((EX*EF2-EI-3.D0*EF)*AX1+4.D0*CORH-124
     1EF2*AX2)/(AF2*EIPF**2))/ES                                        CORH-125
      IF (EF.LT.2.2D0*EI) GO TO 10                                      CORH-126
      WRITE (6,1001) EF,EI                                              CORH-127
      STOP                                                              CORH-128
C CALCULATION OF (0,2;0) AND (0,2;1) .ONLY THE FIRST IS NECESSARY       CORH-129
C   FOR THE DOWNWARD RECURSION. WITH EX=EF-EI >0 ,                      CORH-130
C  (0,2;L) = PI * SQRT(EI*EF)/(2*SH(PI*EX) * ( (Y/EF-1/(Y*EI))/(2*L+1)  CORH-131
C    + (EX/(EF*EI)) * EXP(-PI*EX/2) * REAL PART OF EXP(I*(XEI-XEF))     CORH-132
C    * (EX/2)**(-I*EX) * EI**(I*EF) * EF**(-I*EI) * F3( -L+I*EI ,       CORH-133
C    -L-I*EF, L+1+I*EI , L+1-I*EF , 2-I*EX ; EX/(2*EF) , -EX/(2*EI) )   CORH-134
C    WHERE Y=EXP(PI*EX/2)*(EI/EF)**L*|GAMMA(L+1+I*EF)/GAMMA(L+1+I*EI)|  CORH-135
   10 E=EX/(2*EF)                                                       CORH-136
      EE=-E*EX/(2*EI)                                                   CORH-137
      EEE=E*E                                                           CORH-138
      EFSI=EF/EI                                                        CORH-139
      EISF=EI/EF                                                        CORH-140
      LL=LM*EX.GT.3.D0*EIPF                                             CORH-141
      B1=DEXP(-ZR)/EX/DSQRT(1+EX**2)                                    CORH-142
      B2=XEI-XEF-ZI+DATAN(EX)+1.5707963267948966D0+EF*DLOG(EI)-EI*DLOG(ECORH-143
     1F)-EX*DLOG(0.5D0*EX)                                              CORH-144
      AX3=B1*DCOS(B2)                                                   CORH-145
      AX4=B1*DSIN(B2)                                                   CORH-146
      B3=AX3                                                            CORH-147
      B4=AX4                                                            CORH-148
      C3=DSQRT(EFSI*(DEXP(-6.2831853071795864D0*EI)-1.D0)/(DEXP(-6.28318CORH-149
     153071795864D0*EF)-1.D0))                                          CORH-150
      C4=DEXP(-1.5707963267948966D0*EX)                                 CORH-151
      C5=3.1415926535897932D0*ES*C4**2/(1.D0-C4**4)                     CORH-152
      C4=C4*EX/EIF                                                      CORH-153
      C1=0.D0                                                           CORH-154
      BM(1,1)=1.D0                                                      CORH-155
      BM(2,1)=0.D0                                                      CORH-156
      BM(3,1)=1.D0                                                      CORH-157
      BM(4,1)=0.D0                                                      CORH-158
      DO 15 L=1,2                                                       CORH-159
      LI=L-1                                                            CORH-160
      AM(L)=B3                                                          CORH-161
      C2=0.D0                                                           CORH-162
      N=0                                                               CORH-163
   11 N=N+1                                                             CORH-164
      IF (8*N.GT.LX) CALL MEMO(IDMT,IDMT+8*N-LX,LX,4,LO)                CORH-165
      IF (LO(19)) GO TO 20                                              CORH-166
      C2=C2+1.D0                                                        CORH-167
      B1=C2+1.D0                                                        CORH-168
      B2=B1**2+EX**2                                                    CORH-169
      B7=(B3*B1-EX*B4)/(B2*E)                                           CORH-170
      B4=(B3*EX+B4*B1)/(B2*E)                                           CORH-171
      B3=B7                                                             CORH-172
      B1=(C1+C2)*(C2-C1-1.D0)-EI2                                       CORH-173
      B2=EI*(2.D0*C2-1.D0)                                              CORH-174
      BM(1,N+1)=(BM(1,N)*B1-BM(2,N)*B2)*EEE/C2                          CORH-175
      BM(2,N+1)=(BM(1,N)*B2+BM(2,N)*B1)*EEE/C2                          CORH-176
      B1=(C1+C2)*(C2-C1-1.D0)-EF2                                       CORH-177
      B2=-EF*(2.D0*C2-1.D0)                                             CORH-178
      BM(3,N+1)=(BM(3,N)*B1-BM(4,N)*B2)*EE/C2                           CORH-179
      BM(4,N+1)=(BM(3,N)*B2+BM(4,N)*B1)*EE/C2                           CORH-180
      B5=BM(1,N+1)                                                      CORH-181
      B6=BM(2,N+1)                                                      CORH-182
      DO 12 J=1,N                                                       CORH-183
      M=N+2-J                                                           CORH-184
      B5=B5+BM(1,J)*BM(3,M)-BM(2,J)*BM(4,M)                             CORH-185
   12 B6=B6+BM(2,J)*BM(3,M)+BM(1,J)*BM(4,M)                             CORH-186
      IF (DABS(B5)+DABS(B6).GT.1.D30) GO TO 13                          CORH-187
      B5=B5*B3-B6*B4                                                    CORH-188
      AM(L)=AM(L)+B5                                                    CORH-189
      IF (DABS(B5).LT.DABS(AM(L))*1.D-16) GO TO 14                      CORH-190
      GO TO 11                                                          CORH-191
   13 WRITE (6,1002) N,LI,EI,EF,AM(L),B5,B6                             CORH-192
   14 AM(L)=C5*(C4*AM(L)+(C3/EF-1.D0/(C3*EI))/(2.D0*C1+1.D0))           CORH-193
      IF (LL) GO TO 17                                                  CORH-194
      C1=1.D0                                                           CORH-195
      C3=C3*EISF*AF2/AI2                                                CORH-196
      B2=AF2*AI2                                                        CORH-197
      B1=(1+EIF)/B2                                                     CORH-198
      B2=-EX/B2                                                         CORH-199
      B3=B1*AX3-B2*AX4                                                  CORH-200
   15 B4=B1*AX4+B2*AX3                                                  CORH-201
C RECURSION RELATION FOR  (0,2;L) :                                     CORH-202
C    ((2*L+1)/(2*L+3))*(L+2)**2*|L+1+I*EI|*|L+1+I*EF|*(0,2;L) -         CORH-203
C  (EI*EF*((L+1)**2+(L+2)**2)+(L+1)**2*(L+2)**2*(EI/EF+EF/EI))*(0,2;L+1)CORH-204
C  + ((2*L+5)/(2*L+3))*(L+1)**2*|L+2+I*EI|*|L+2+I*EF|*(0,2:L+2) =       CORH-205
C    2*EI*(L+1)*|L+2+I*EI|*(1,2;L+1) - 2*EF*(L+2)*|L+1+I*EI|*(1,2;L)    CORH-206
C OR 2*EF*(L+1)*|L+2+I*EI|*(-1,2;L+2) - 2*EI*(L+2)*|L+1+I*EF|*(-1,2;L+1)CORH-207
C RECURSION RELATION FOR (1,2;L) :                                      CORH-208
C  2*EI*EF*|L+I*EI|*|L+1+I*EF|*(1,2;L-1) - (4*EI**2*EF**2+(L+1)*(2*L+3)*CORH-209
C    EF**2+(L+1)*(2*L+1)*EI**2)*(1,2;L) + 2*EI*EF*|L+1+I*EI|*|L+2+I*EF|*CORH-210
C    (1,2;L+1) . BECAUSE OF THE VERY SLOW DECREASE WHEN EF>EI,          CORH-211
C    (-1,2;L) IS USED FOR UPWARD RECURSION AND (1,2;L) FOR THE          CORH-212
C    DOWNWARD RECURSION.                                                CORH-213
      C2=1.D0                                                           CORH-214
      C3=4.D0                                                           CORH-215
      C4=2.D0                                                           CORH-216
      DO 16 I=3,LM                                                      CORH-217
      AI1=AI2                                                           CORH-218
      AI2=AI3                                                           CORH-219
      AF1=AF2                                                           CORH-220
      AM1=AM2                                                           CORH-221
      AM2=AM3                                                           CORH-222
      C4=C4+1.D0                                                        CORH-223
      C1=C2                                                             CORH-224
      C2=C3                                                             CORH-225
      C3=C4**2                                                          CORH-226
      AI3=DSQRT(C3+EI2)                                                 CORH-227
      AF2=DSQRT(C2+EF2)                                                 CORH-228
      AM(I)=((2.D0*C4-3.D0)*(EIF*(C1+C2)+C1*C2*EITF)*AM(I-1)-(2.D0*C4-5.CORH-229
     1D0)*C2*AF1*AI1*AM(I-2)+2.D0*(2.D0*C4-3.D0)*(EF*(C4-2.D0)*AI2*AM2-ECORH-230
     2I*(C4-1.D0)*AF1*AM1))/((2.D0*C4-1.D0)*C1*AF2*AI2)                 CORH-231
      IF (AM(I).LT.0.D0) GO TO 17                                       CORH-232
   16 AM3=((2.D0*EIF+C2*EITF-(C4-1.D0)*EIMF)*AM2-AF1*AI2*AM1)/(AF2*AI3) CORH-233
      RETURN                                                            CORH-234
C DOWNWARD RECURSION . TO AVOID TAKING THE ROOT THE FOLLOWING ARE USED  CORH-235
C <0,2;L> = (EF/EI)**L * |GAMMA(L+1+I*EF)/GAMMA(L+1+I*EI)| * (0,2;L)    CORH-236
C <1,2;L> = (EF/EI)**L * |GAMMA(L+2+I*EF)/GAMMA(L+1+I*EI)| * (1,2;L)    CORH-237
   17 LK=5.D0*EIPF/EX                                                   CORH-238
      LK=LM+LK+1                                                        CORH-239
      B1=1.D0                                                           CORH-240
      B2=0.D0                                                           CORH-241
      B3=B2                                                             CORH-242
      C3=LK-1                                                           CORH-243
      C2=C3**2                                                          CORH-244
C AT THE END OF THIS LOOP                                               CORH-245
C B1=<1,2;L>/<1,2;L-1>    B2=<0,2,L-1>/<1,2;L-1>    B3=<0,2;L>/<1,2;L-1>CORH-246
      DO 18 I=3,LK                                                      CORH-247
      L=LK+2-I                                                          CORH-248
      C3=C3-1.D0                                                        CORH-249
      C1=C2                                                             CORH-250
      C2=C3**2                                                          CORH-251
      B1=EF2*(C1+EF2)/(EIF*(2.D0*EIF+C1*EITF+(C3+1.D0)*EIMF)-(C1+EI2)*B1CORH-252
     1*EI2)                                                             CORH-253
      A1=-EI2*C2*(C1+EI2)*B3*B1/EF2                                     CORH-254
      B3=B2*B1                                                          CORH-255
      B2=(2.D0*(2.D0*C3+1.D0)*(C3*EI2*B1/EF-(C3+1.D0)*EF)+A1+(EI2*(C1+C2CORH-256
     1)+C1*C2*(EI2/EF2+1.D0))*B3)/(C1*(C2+EF2))                         CORH-257
      IF (L.LE.LM) AM(L)=B3/B2                                          CORH-258
   18 CONTINUE                                                          CORH-259
      A1=B2*AZ*AF2                                                      CORH-260
C CALCULATION OF THE MIXTURE OF THE DECREASING SOLUTION OF THE HOMOGEN- CORH-261
C EOUS EQUATION  (EI/EF)**L * |GAMMA(L+1+I*EF)/GAMMA(L+1+I*EI)|/(2*L+1) CORH-262
      A2=AM(1)-A1                                                       CORH-263
      A3=0.D0                                                           CORH-264
      DO 19 I=2,LM                                                      CORH-265
      A3=A3+1.D0                                                        CORH-266
      A4=DSQRT((A3**2+EF2)/(A3**2+EI2))                                 CORH-267
      A2=A2*EISF*A4                                                     CORH-268
      A1=A1*EISF*AM(I)/A4                                               CORH-269
   19 AM(I)=(A1+A2)/(2.D0*A3+1.D0)                                      CORH-270
      RETURN                                                            CORH-271
   20 WRITE (6,1003)                                                    CORH-272
      STOP                                                              CORH-273
 1000 FORMAT (40H NO CONVERGENCE WITH 500 TERMS FOR (0,1;,I1,11H) WITH ECORH-274
     1I =,F15.6,10X,8HAND EF =,F15.6,5X,7HIN CORH/5X,7HVALUE =,D17.8,5X,CORH-275
     211HLAST TERM =,2D16.8)                                            CORH-276
 1001 FORMAT (24H EF/EI RATIO TOO GREAT =,F15.6,1H/,F15.6,5X,20HINCORH  CORH-277
     1   .... STOP)                                                     CORH-278
 1002 FORMAT (21H NO CONVERGENCE WITH ,I4,15H TERM FOR (0,2;,I1,14H)    CORH-279
     1WITH EI =,F15.6,5X,8HAND EF =,F15.6,5X,7HIN CORH/5X,7HVALUE =,D15.CORH-280
     28,5X,11HLAST TERM =,2D15.8)                                       CORH-281
 1003 FORMAT (25H ***** STOP IN CORH *****)                             CORH-282
      END                                                               CORH-283
