C 07/12/98                                                      DWBB98  LECB-000
      SUBROUTINE LECB(JKJ,MPAR,LMX,COF,XG,IJ1,IJ2,LMJ,W,FAC,NFA)        LECB-001
C READ AND PLACE RESULTS OF INELASTIC SCATTERING                        LECB-002
C INPUT:   JKJ:    VALUE OF J TRANSFERRED                               LECB-003
C          MPAR:   1 FOR NATURAL PARITY, -1 FOR UNNATURAL PARITY.       LECB-004
C          LMX:    NUMBER OF J VALUES FOR ELASTIC SCATTERING.           LECB-005
C          COF:    NORMALISATION COEFFICIENT.                           LECB-006
C          XG:     COULOMB PHASE SHIFTS.                                LECB-007
C          IJ1:    NUMBER OF SOLUTIONS.                                 LECB-008
C          IJ2:    NUMBER OF COMPONENTS.                                LECB-009
C          LMJ:    NUMBER OF J VALUES FOR FINAL RESULTS.                LECB-010
C          W:      TABLE OF C-MATRIX TO UPDATE.                         LECB-011
C          FAC:    LOGARITHMS OF FACTORIALS.                            LECB-012
C          NFA:    NUMBER OF VALUES IN FAC.                             LECB-013
C OUTPUT:  W(*,*,*,*):     UPDATED SCATTERING MATRIX:                   LECB-014
C                W(1,*,*,*), W(2,*,*,*): REAL AND IMAGINARY PARTS,      LECB-015
C                W(*,I,J,K):   ITH COMPONENT OF THE JTH SOLUTION AND    LECB-016
C                              THE KTH TOTAL ANGULAR MOMENTUM.          LECB-017
C***********************************************************************LECB-018
      IMPLICIT REAL*8 (A-H,O-Z)                                         LECB-019
      DIMENSION XG(2,1),W(2,LMJ,IJ2,IJ1,2),FAC(1)                       LECB-020
      DATA PI /3.1415926535897932D0/                                    LECB-021
      KJJ=2*JKJ+1                                                       LECB-022
      NM=MOD(IJ1,2)-2                                                   LECB-023
      NK=0                                                              LECB-024
      NQ=MOD(JKJ,2)+MPAR+1                                              LECB-025
      IF (NQ.EQ.0) NK=1                                                 LECB-026
      NP=MIN0(MOD(NQ,3),1)                                              LECB-027
      NQ=NQ+JKJ/2+IJ1/2                                                 LECB-028
      DO 3 I=1,LMX                                                      LECB-029
      LI1=2*(I/2)                                                       LECB-030
      LI2=2*I-1-LI1                                                     LECB-031
      JI=2*I-1                                                          LECB-032
      DO 2 J=1,KJJ                                                      LECB-033
      JF=JI-2*JKJ+2*J-2                                                 LECB-034
      LL=I+J-2-JKJ                                                      LECB-035
      SILJ=1-2*MOD(I,2)                                                 LECB-036
      L1=LL                                                             LECB-037
      L2=LL                                                             LECB-038
      IF (MOD(L1,2).EQ.NP) L1=L1+1                                      LECB-039
      IF (MOD(L2,2).NE.NP) L2=L2+1                                      LECB-040
      IF (JF.LT.IABS(2*JKJ-JI)) GO TO 2                                 LECB-041
      IF (LL.GE.LMX) GO TO 2                                            LECB-042
      READ (5,1000) A1,A2,A3,A4                                         LECB-043
      KIMJ=(100+LI1-L1+JI-JF+JKJ)/2                                     LECB-044
      SIMJ=1-2*MOD(KIMJ+I+NK,2)                                         LECB-045
      Z1=(A1+SILJ*A3)*COF*SIMJ                                          LECB-046
      Z2=(A2+SILJ*A4)*COF*SIMJ                                          LECB-047
      Z3=DCOS(-XG(1,LI1+1)-XG(2,L1+1)+(L1-LI1)*PI*.5D0)                 LECB-048
      Z4=DSIN(-XG(1,LI1+1)-XG(2,L1+1)+(L1-LI1)*PI*.5D0)                 LECB-049
      B1=Z1*Z3-Z2*Z4                                                    LECB-050
      B2=Z1*Z4+Z2*Z3                                                    LECB-051
      KIMJ=(100+LI2-L2+JI-JF+JKJ)/2                                     LECB-052
      SIMJ=1-2*MOD(KIMJ+I+NK,2)                                         LECB-053
      Z1=-(A1-SILJ*A3)*COF*SIMJ                                         LECB-054
      Z2=-(A2-SILJ*A4)*COF*SIMJ                                         LECB-055
      Z3=DCOS(-XG(1,LI2+1)-XG(2,L2+1)+(L2-LI2)*PI*.5D0)                 LECB-056
      Z4=DSIN(-XG(1,LI2+1)-XG(2,L2+1)+(L2-LI2)*PI*.5D0)                 LECB-057
      B3=Z1*Z3-Z2*Z4                                                    LECB-058
      B4=Z1*Z4+Z2*Z3                                                    LECB-059
      IMIN=MAX0((2*I-IJ1+2)/2,1)                                        LECB-060
      IMAX=MIN0((2*I+IJ1)/2,LMJ)                                        LECB-061
      DO 1 K=IMIN,IMAX                                                  LECB-062
      JJ=IJ1/2+I-K+1                                                    LECB-063
      IF (JJ.LT.1.OR.JJ.GT.IJ1) GO TO 1                                 LECB-064
      JH=IJ2/2+I-K+J-JKJ                                                LECB-065
      IF (JH.LT.1.OR.JH.GT.IJ2) GO TO 1                                 LECB-066
      JR=MOD(K+1,2)+1                                                   LECB-067
      JQ=3-JR                                                           LECB-068
      B5=(2.D0*JKJ+1.D0)*DSQRT(DFLOAT(IJ1))*(2*MOD(I+K+J+NQ,2)-1)       LECB-069
      B5=B5*DJ6J(JI,JF,2*JKJ,IJ2-1,IJ1-1,2*K+NM,FAC,NFA)                LECB-070
      W(1,K,JH,JJ,JR)=W(1,K,JH,JJ,JR)+B1*B5                             LECB-071
      W(2,K,JH,JJ,JR)=W(2,K,JH,JJ,JR)+B2*B5                             LECB-072
      W(1,K,JH,JJ,JQ)=W(1,K,JH,JJ,JQ)+B3*B5                             LECB-073
      W(2,K,JH,JJ,JQ)=W(2,K,JH,JJ,JQ)+B4*B5                             LECB-074
    1 CONTINUE                                                          LECB-075
    2 SIMJ=-SIMJ                                                        LECB-076
    3 CONTINUE                                                          LECB-077
      RETURN                                                            LECB-078
 1000 FORMAT (4D18.10)                                                  LECB-079
      END                                                               LECB-080
